@@ -3,7 +3,7 @@
 #' Send a cancel signal for a particular order to RobinHood. You will need to retain the buy/sell order url returned from place_order.
 #'
 #' @param RH object of class RobinHood
-#' @param order_url (string) cancel url returned from place_order()
+#' @param cancel_url (string) cancel url returned from place_order()
 #' @import httr magrittr
 #' @export
 #' @examples
@@ -22,13 +22,13 @@
 #'                  side = "buy")           # buy or sell
 #'
 #' # Cancel the order, should also generate an email confirmation
-#' cancel_order(RH, x$cancel)
+#' cancel_order(RH, x$cancel_url)
 #'}
-cancel_order <- function(RH, order_url) {
+cancel_order <- function(RH, cancel_url) {
 
   check_rh(RH)
 
-  order_status <- api_orders(RH, action = "cancel", order_url)
+  order_status <- api_orders(RH, action = "cancel", cancel_url = cancel_url)
 
   if (length(order_status) == 0) cat("Order Canceled")
 
